accfifo: A FIFO accounting calculator
=====================================

.. image:: https://travis-ci.org/vst/accfifo.svg?branch=develop

``TODO: Provide a complete README file``

Usage
-----

Check tests to see examples.

License
-------

This library is licensed under `BSD 2-Clause <http://opensource.org/licenses/BSD-2-Clause>`_.
